@@ -8,6 +8,4 @@ def pytest_sessionstart(session):
         "_system",
         username=settings.ARANGODB_USERNAME,
         password=settings.ARANGODB_PASSWORD,
-    )
-    if not sys_db.has_database(settings.ARANGODB_DATABASE):
-        sys_db.create_database(settings.ARANGODB_DATABASE)
+    )
\ No newline at end of file
